from setuptools import setup

setup(
    name='lilliepy-head',
    version='1.0',
    packages=['lilliepy_head'],
    install_requires=[
        'reactpy'
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    description='helps with head related stuff in the lilliepy framework',
    keywords=[
        "lilliepy", "lilliepy-head", "reactpy"
    ],
    url='https://github.com/websitedeb/lilliepy-head',
    author='Sarthak Ghoshal',
    author_email='sarthak22.ghoshal@gmail.com',
    license='MIT',
    python_requires='>=3.6',
)